==> v1.42.tar.gz: dmolony-diskbrowser/README.md <==
# Apple II Disk Browser

### Features
- Cross-platform (Windows, MacOS, Linux)
- Applesoft and Integer Basic
- Pascal disassembler
- 6502 disassembler
- Wizardry internals and maps
- Infocom text adventure internals
- Appleworks
- Visicalc
- HDV and 2mg
- Compressed disks - shrinkIt, gzip, zip
- Track and sector display
- Dual DOS disks
- DOS 4.1 disks
- CPM disks
- Comprehensive disk listing
- woz format disks
- UniDos disks

### Documentation
* [Usage](resources/usage.md)

### Installation
* Install the **latest** version of the [Java Runtime Environment](http://www.oracle.com/technetwork/java/javase/downloads/index.html) (JRE or JDK).
* Download DiskBrowser.jar from the [releases](https://github.com/dmolony/diskbrowser/releases) page.
* Double-click the jar file, or enter 'java -jar DiskBrowser.jar' in the terminal.
* Set your root folder (the top-level folder where you keep your disk images).

### Example Screens
#### Disk listing
Select a disk from the Disk Tree tab to display the catalog and disk layout.
![Disk listing](resources/disk1.png?raw=true "Disk listing")
#### Disk contents
Double-click a disk from the Disk Tree tab and a new tab appears. This tab contains a list of all the files on the disk. Click on a file and the Output panel will display the contents of that file. The disk sectors containing the file will also be highlighted in the Disk Layout panel.
![Disk catalog](resources/disk2.png?raw=true "Disk catalog")
#### Detailed sector display
Click on any sector in the Disk Layout panel and the Output panel will display the contents of that sector. If it is a recognised sector type, it will be formatted for easier reading.
![Sector details](resources/sector.png?raw=true "Sector details")
#### Windows
![Windows](resources/windows.png?raw=true "Windows")
#### Hard disk
![Hard disk](resources/disk3.png?raw=true "Hard disk")
#### Pascal code
![Pascal](resources/pascal.png?raw=true "Pascal")
#### Infocom
![Infocom](resources/zork.png?raw=true "Infocom")
#### Graphics 
![Graphics](resources/planetfall.png?raw=true "Graphics")
#### Wizardry
![Wizardry](resources/wizardry.png?raw=true "Wizardry")
#### Visicalc
![Visicalc](resources/visicalc.png?raw=true "Visicalc")
#### Complete Disk List
![Disk List](resources/disklist.png?raw=true "Disk List")

==> 1.45.tar.gz: dmolony-diskbrowser/README.md <==
# Apple II Disk Browser

### Features
- Cross-platform (Windows, MacOS, Linux)
- Applesoft and Integer Basic
- Pascal disassembler
- 6502 disassembler
- Wizardry internals and maps
- Infocom text adventure internals
- Appleworks
- Visicalc
- HDV and 2mg
- Compressed disks - shrinkIt, gzip, zip
- Track and sector display
- Dual DOS disks
- DOS 4.1 disks
- CPM disks
- Comprehensive disk listing
- woz format disks
- UniDos disks

### Documentation
* [Usage](resources/usage.md)

### Installation
* Install the **latest** version of the [Java Runtime Environment](http://www.oracle.com/technetwork/java/javase/downloads/index.html) (JRE or JDK).
* Download DiskBrowser.jar from the [releases](https://github.com/dmolony/diskbrowser/releases) page.
* Double-click the jar file, or enter 'java -jar DiskBrowser.jar' in the terminal.
* Set your root folder (the top-level folder where you keep your disk images).

### Example Screens
#### Disk listing
Select a disk from the Disk Tree tab to display the catalog and disk layout.
![Disk listing](resources/disk1.png?raw=true "Disk listing")
#### Disk contents
Double-click a disk from the Disk Tree tab and a new tab appears. This tab contains a list of all the files on the disk. Click on a file and the Output panel will display the contents of that file. The disk sectors containing the file will also be highlighted in the Disk Layout panel.
![Disk catalog](resources/disk2.png?raw=true "Disk catalog")
#### Detailed sector display
Click on any sector in the Disk Layout panel and the Output panel will display the contents of that sector. If it is a recognised sector type, it will be formatted for easier reading.
![Sector details](resources/sector.png?raw=true "Sector details")
#### Windows
![Windows](resources/windows.png?raw=true "Windows")
#### Hard disk
![Hard disk](resources/disk3.png?raw=true "Hard disk")
#### Pascal code
![Pascal](resources/pascal.png?raw=true "Pascal")
#### Infocom
![Infocom](resources/zork.png?raw=true "Infocom")
#### Graphics 
![Graphics](resources/graphics.png?raw=true "Graphics")
#### Wizardry
![Wizardry](resources/wizardry.png?raw=true "Wizardry")
#### Visicalc
![Visicalc](resources/visicalc.png?raw=true "Visicalc")
#### Complete Disk List
![Disk List](resources/disklist.png?raw=true "Disk List")
